@@ -6,6 +6,7 @@ import os
 import numpy as np
 import pandas as pd
 from iexfinance.stocks import get_historical_intraday
+from tensorflow.keras.models import load_model
 
 R = '#ff0000'
 G = '#55ff00'
@@ -23,7 +24,7 @@ os.environ['IEX_TOKEN'] = TOKEN
 __author__ = 'Vlad Kochetov'
 __credits__ = ["Hemerson Tacon -- Stack overflow",
                "hpaulj -- Stack overflow"]
-__version__ = "v2.1.7"
+__version__ = "2.1.9"
 
 TICKER = '^DJI'
 SCATTER_SIZE = 12
@@ -39,8 +40,8 @@ DEPO_COLOR_DOWN = 'red'
 logger = logging.getLogger()
 logger.setLevel(50)
 logging.basicConfig(level=10, filename='trading.log')
-
-
+MODEL_PREDICTING = load_model('../model_predicting')
+MODEL_REGRESSION = load_model('../model_regression')
 def set_(data):
     ret = list(data.copy())
     for e, i in enumerate(data[1:]):
